Office.onReady((info) => {
  if (info.host === Office.HostType.Outlook) {
    const sideloadMsg = document.getElementById("sideload-msg");
    const appBody = document.getElementById("app-body");
    const runButton = document.getElementById("run");

    if (sideloadMsg && appBody && runButton) {
      sideloadMsg.style.display = "none";
      appBody.style.display = "flex";
      runButton.onclick = run;
    }
  }
});

export async function run() {
  try {
    if (Office.context && Office.context.mailbox) {
      const item = Office.context.mailbox.item;

      // Check if 'item' is defined before accessing its properties.
      if (item) {
        // Check if it's an outgoing email (compose mode).
        if (item.itemType === Office.MailboxEnums.ItemType.Message) {
          // Capture email details.
          const from = item.from;
          const toRecipients = item.to;
          const ccRecipients = item.cc;
          const bccRecipients = item.bcc;
          const subject = item.subject;
          // Use the captured data as needed.
          console.log('From:', from);
          console.log('To:', toRecipients);
          console.log('CC:', ccRecipients);
          console.log('BCC:', bccRecipients);
          console.log('Subject:', subject);

          // Get the email body asynchronously.
          item.body.getAsync(Office.CoercionType.Text, (result) => {
            if (result.status === Office.AsyncResultStatus.Succeeded) {
              // result.value is valid, so you can access its properties.
              const emailBody = result.value;
              console.log('Body:', emailBody);
              // Save the email details to a text file.
              const emailDetails = `From: ${from}\nTo: ${toRecipients}\nCC: ${ccRecipients}\nBCC: ${bccRecipients}\nSubject: ${subject}\nBody: ${emailBody}`;
              saveToFile('email_details.txt', emailDetails);
            } else {
              console.error('Error getting email body:', result.error);
            }
          });
        } else {
          console.log('This is not a compose mode (outgoing) email.');
        }
      } else {
        console.error("Office.context or Office.context.mailbox is null.");
      }
    }
  } catch (error) {
    console.error("Error capturing email details:", error);
  }
}

function saveToFile(filename, content) {
  const blob = new Blob([content], { type: 'text/plain' });
  const url = window.URL.createObjectURL(blob);
  const a = document.createElement('a');
  a.href = url;
  a.download = filename;
  document.body.appendChild(a);
  a.click();
  window.URL.revokeObjectURL(url);
}
